@@ -18,6 +18,10 @@ use dactyl::{
 	traits::SaturatingFrom,
 	write_time,
 };
+
+#[cfg(feature = "parking_lot_mutex")]
+use parking_lot::Mutex;
+
 use std::{
 	borrow::Borrow,
 	cmp::Ordering,
@@ -33,7 +37,6 @@ use std::{
 	},
 	sync::{
 		Arc,
-		Mutex,
 		atomic::{
 			AtomicBool,
 			AtomicU8,
@@ -49,6 +52,9 @@ use std::{
 	},
 };
 
+#[cfg(not(feature = "parking_lot_mutex"))]
+use std::sync::Mutex;
+
 
 
 /// # (Not) Random State.
@@ -105,6 +111,7 @@ const TASK_PREFIX: &[u8; 8] = &[32, 32, 32, 32, 226, 134, 179, 32];
 
 
 
+#[cfg(not(feature = "parking_lot_mutex"))]
 /// # Helper: Mutex Unlock.
 ///
 /// This just moves tedious code out of the way.
@@ -114,6 +121,14 @@ macro_rules! mutex_ptr {
 	);
 }
 
+#[cfg(feature = "parking_lot_mutex")]
+/// # Helper: Mutex Unlock.
+///
+/// This just moves tedious code out of the way.
+macro_rules! mutex_ptr {
+	($mutex:expr) => ( $mutex.lock() );
+}
+
 
 
 #[derive(Debug, Copy, Clone)]
@@ -491,6 +506,7 @@ impl ProglessInner {
 		}
 	}
 
+	#[allow(clippy::option_if_let_else)] // This is better.
 	/// # Set Title.
 	///
 	/// Give the progress bar a title, which will be shown above the progress
@@ -804,6 +820,7 @@ impl ProglessInner {
 		}
 	}
 
+	#[allow(clippy::option_if_let_else)] // This is better.
 	/// # Tick Title.
 	///
 	/// The title needs to be rewritten both on direct change and resolution
@@ -1058,6 +1075,7 @@ impl From<Progless> for Msg {
 
 /// # Construction/Destruction.
 impl Progless {
+	#[must_use]
 	/// # With Title.
 	///
 	/// Add a title to the progress bar. When present, this will print on its
